@@ -6,7 +6,7 @@ class UploadcareException(Exception):
     """Base exception class of library."""
     def __init__(self, data='', *args, **kwargs):
         self.data = str(data)
-        super(UploadcareException, self).__init__(*args, **kwargs)
+        super(UploadcareException, self).__init__(data, *args, **kwargs)
 
 
 class APIConnectionError(UploadcareException):
